# LCLS

LCLS-specific whatrecord plugins and helpers.

::: whatrecord.iocmanager

## ``whatrecord iocmanager-loader``

``whatrecord iocmanager-loader`` is used to import IOC configuration
information from SLAC PCDS IocManager-format configuration files.

```
usage: whatrecord iocmanager-loader [-h] configs [configs ...]

"whatrec iocmanager_loader" is used to import IOC configuration information
from SLAC PCDS IocManager-format configuration files.

positional arguments:
  configs     Configuration file location(s)

optional arguments:
  -h, --help  show this help message and exit
```

::: whatrecord.bin.iocmanager_loader

## API
::: whatrecord.plugins.epicsarch
::: whatrecord.plugins.twincat_pytmc
